=== modified file 'TODO'
--- TODO	2011-11-09 17:16:03 +0000
+++ TODO	2011-11-29 19:25:06 +0000
@@ -41,9 +41,8 @@
 
 * mandos (server)
 ** TODO [#B] Log level							  :BUGS:
+** TODO [#A] Save state to new file and move instead of overwrite
   
-*** TODO /etc/mandos/clients.d/*.conf
-    Watch this directory and add/remove/update clients?
 ** TODO [#C] config for TXT record
 ** TODO Log level option
    syslogger.setLevel(logging.WARNING)

=== modified file 'mandos'
--- mandos	2011-11-27 19:37:54 +0000
+++ mandos	2011-11-29 20:58:01 +0000
@@ -128,11 +128,12 @@
     logger.setLevel(level)
 
 
-class CryptoError(Exception):
+class PGPError(Exception):
+    """Exception if encryption/decryption fails"""
     pass
 
 
-class Crypto(object):
+class PGPEngine(object):
     """A simple class for OpenPGP symmetric encryption & decryption"""
     def __init__(self):
         self.gnupg = GnuPGInterface.GnuPG()
@@ -184,7 +185,7 @@
                     ciphertext = f.read()
                 proc.wait()
             except IOError as e:
-                raise CryptoError(e)
+                raise PGPError(e)
         self.gnupg.passphrase = None
         return ciphertext
     
@@ -201,7 +202,7 @@
                     decrypted_plaintext = f.read()
                 proc.wait()
             except IOError as e:
-                raise CryptoError(e)
+                raise PGPError(e)
         self.gnupg.passphrase = None
         return decrypted_plaintext
 
@@ -575,7 +576,7 @@
         self.checker_callback_tag = None
         self.checker = None
         if os.WIFEXITED(condition):
-            self.last_checker_status =  os.WEXITSTATUS(condition)
+            self.last_checker_status = os.WEXITSTATUS(condition)
             if self.last_checker_status == 0:
                 logger.info("Checker for %(name)s succeeded",
                             vars(self))
@@ -1068,21 +1069,21 @@
         datetime_to_dbus, "LastApprovalRequest")
     approved_by_default = notifychangeproperty(dbus.Boolean,
                                                "ApprovedByDefault")
-    approval_delay = notifychangeproperty(dbus.UInt16,
+    approval_delay = notifychangeproperty(dbus.UInt64,
                                           "ApprovalDelay",
                                           type_func =
                                           timedelta_to_milliseconds)
     approval_duration = notifychangeproperty(
-        dbus.UInt16, "ApprovalDuration",
+        dbus.UInt64, "ApprovalDuration",
         type_func = timedelta_to_milliseconds)
     host = notifychangeproperty(dbus.String, "Host")
-    timeout = notifychangeproperty(dbus.UInt16, "Timeout",
+    timeout = notifychangeproperty(dbus.UInt64, "Timeout",
                                    type_func =
                                    timedelta_to_milliseconds)
     extended_timeout = notifychangeproperty(
-        dbus.UInt16, "ExtendedTimeout",
+        dbus.UInt64, "ExtendedTimeout",
         type_func = timedelta_to_milliseconds)
-    interval = notifychangeproperty(dbus.UInt16,
+    interval = notifychangeproperty(dbus.UInt64,
                                     "Interval",
                                     type_func =
                                     timedelta_to_milliseconds)
@@ -1279,7 +1280,7 @@
     def Host_dbus_property(self, value=None):
         if value is None:       # get
             return dbus.String(self.host)
-        self.host = value
+        self.host = unicode(value)
     
     # Created - property
     @dbus_service_property(_interface, signature="s", access="read")
@@ -1379,7 +1380,7 @@
     def Checker_dbus_property(self, value=None):
         if value is None:       # get
             return dbus.String(self.checker_command)
-        self.checker_command = value
+        self.checker_command = unicode(value)
     
     # CheckerRunning - property
     @dbus_service_property(_interface, signature="b",
@@ -2218,7 +2219,7 @@
             if e.errno != errno.ENOENT:
                 raise
     
-    with Crypto() as crypt:
+    with PGPEngine() as pgp:
         for client in clients_data:
             client_name = client["name"]
             
@@ -2235,7 +2236,7 @@
                     if (name != "secret" and
                         value != old_client_settings[client_name]
                         [name]):
-                        setattr(client, name, value)
+                        client[name] = value
                 except KeyError:
                     pass
             
@@ -2243,10 +2244,10 @@
             # enabled if its last checker was sucessful.  Clients
             # whose checker failed before we stored its state is
             # assumed to have failed all checkers during downtime.
-            if client["enabled"] and client["last_checked_ok"]:
-                if ((datetime.datetime.utcnow()
-                     - client["last_checked_ok"])
-                    > client["interval"]):
+            if client["enabled"]:
+                if client["expires"] <= (datetime.datetime
+                                         .utcnow()):
+                    # Client has expired
                     if client["last_checker_status"] != 0:
                         client["enabled"] = False
                     else:
@@ -2284,12 +2285,14 @@
             
             try:
                 tcp_server.clients[client_name].secret = (
-                    crypt.decrypt(tcp_server.clients[client_name]
-                                  .encrypted_secret,
-                                  client_settings[client_name]
-                                  ["secret"]))
-            except CryptoError:
+                    pgp.decrypt(tcp_server.clients[client_name]
+                                .encrypted_secret,
+                                client_settings[client_name]
+                                ["secret"]))
+            except PGPError:
                 # If decryption fails, we use secret from new settings
+                logger.debug("Failed to decrypt {0} old secret"
+                             .format(client_name))
                 tcp_server.clients[client_name].secret = (
                     client_settings[client_name]["secret"])
     
@@ -2395,11 +2398,11 @@
         # based on what config file has. If config file is
         # removed/edited, old secret will thus be unrecovable.
         clients = []
-        with Crypto() as crypt:
+        with PGPEngine() as pgp:
             for client in tcp_server.clients.itervalues():
                 key = client_settings[client.name]["secret"]
-                client.encrypted_secret = crypt.encrypt(client.secret,
-                                                        key)
+                client.encrypted_secret = pgp.encrypt(client.secret,
+                                                      key)
                 client_dict = {}
                 
                 # A list of attributes that will not be stored when

=== modified file 'mandos-ctl'
--- mandos-ctl	2011-10-15 16:48:03 +0000
+++ mandos-ctl	2011-11-29 20:30:21 +0000
@@ -93,29 +93,23 @@
     >>> string_to_delta("5m 30s")
     datetime.timedelta(0, 330)
     """
-    timevalue = datetime.timedelta(0)
-    regexp = re.compile("\d+[dsmhw]")
+    value = datetime.timedelta(0)
+    regexp = re.compile("(\d+)([dsmhw]?)")
     
-    for s in regexp.findall(interval):
-        try:
-            suffix = unicode(s[-1])
-            value = int(s[:-1])
-            if suffix == "d":
-                delta = datetime.timedelta(value)
-            elif suffix == "s":
-                delta = datetime.timedelta(0, value)
-            elif suffix == "m":
-                delta = datetime.timedelta(0, 0, 0, 0, value)
-            elif suffix == "h":
-                delta = datetime.timedelta(0, 0, 0, 0, 0, value)
-            elif suffix == "w":
-                delta = datetime.timedelta(0, 0, 0, 0, 0, 0, value)
-            else:
-                raise ValueError
-        except (ValueError, IndexError):
-            raise ValueError
-        timevalue += delta
-    return timevalue
+    for num, suffix in regexp.findall(interval):
+        if suffix == "d":
+            value += datetime.timedelta(int(num))
+        elif suffix == "s":
+            value += datetime.timedelta(0, int(num))
+        elif suffix == "m":
+            value += datetime.timedelta(0, 0, 0, 0, int(num))
+        elif suffix == "h":
+            value += datetime.timedelta(0, 0, 0, 0, 0, int(num))
+        elif suffix == "w":
+            value += datetime.timedelta(0, 0, 0, 0, 0, 0, int(num))
+        elif suffix == "":
+            value += datetime.timedelta(0, 0, 0, int(num))
+    return value
 
 def print_clients(clients, keywords):
     def valuetostring(value, keyword):

